Struct dns_parser::Name
[−]
[src]
pub struct Name<'a> { /* fields omitted */ }The DNS name as stored in the original packet
This is contains just a reference to a slice that contains the data.
You may turn this into a string using .to_string()
Methods
impl<'a> Name<'a>[src]
fn scan(data: &'a [u8], original: &'a [u8]) -> Result<Name<'a>, Error>[src]
Scan the data to get Name object
The data should be a part of original where name should start.
The original is the data starting a the start of a packet, so
that offsets in compressed name starts from the original.
fn byte_len(&self) -> usize[src]
Number of bytes serialized name occupies