Crate dns_parser [−] [src]
The network-agnostic DNS parser library
Documentation | Github | Crate
Use Builder to create a new outgoing packet.
Use Packet::parse to parse a packet into a data structure.
Structs
| Builder |
Allows to build a DNS packet |
| Header |
Represents parsed header of the packet |
| Name |
The DNS name as stored in the original packet |
| OptRecord |
RFC 6891 OPT RR |
| Packet |
Parsed DNS packet |
| Question |
A parsed chunk of data in the Query section of the packet |
| ResourceRecord |
A single DNS record |
| SoaRecord |
The SOA (Start of Authority) record |
Enums
| Class |
The CLASS value according to RFC 1035 |
| Error |
Error parsing DNS packet |
| Opcode |
The OPCODE value according to RFC 1035 |
| QueryClass |
The QCLASS value according to RFC 1035 |
| QueryType |
The QTYPE value according to RFC 1035 |
| RRData |
The enumeration that represents known types of DNS resource records data |
| ResponseCode |
The RCODE value according to RFC 1035 |
| Type |
The TYPE value according to RFC 1035 |